@@ -305,7 +305,7 @@ void UI::openUrlDialog()
 void UI::urlDialogAccepted()
 {
   QString tmpstr=urldialog->getUrl();
-  if(!tmpstr.isNull())
+  if((!tmpstr.isNull())&&(!tmpstr.isEmpty()))
   {
     QStringList tmplist;
     tmplist.append(tmpstr);
