@@ -17,7 +17,12 @@ UIPlaylist::UIPlaylist(Player* parent)
 	
 
 //	buttonDel = new QPushButton(tr("Remove"));
-	buttonDel = new QPushButton(s->standardIcon(QStyle::SP_DialogNoButton),"");
+#ifdef Q_WS_MAEMO_5
+	buttonDel = new QPushButton(s->standardIcon(QStyle::SP_TitleBarCloseButton),"");
+#else
+	buttonDel = new QPushButton(s->standardIcon(QStyle::SP_DialogDiscardButton),"");
+#endif
+	
 	
 	//buttonDel->setFixedHeight(40);
 
@@ -156,27 +161,12 @@ void UIPlaylist::upItem()
  
  if(row>0)
  {
-  QListWidgetItem *item  = widgetPlaylist->item(row);
-  QString tmpString=item->text();
-  QBrush tmpbrush=item->foreground();
-  QFont tmpfont=item->font();
-  
-  QListWidgetItem* item2 = widgetPlaylist->item(row-1);
-  QString tmpString2=item2->text();
-  QBrush tmpbrush2=item2->foreground();
-  QFont tmpfont2=item2->font();
-  
-  item->setText(tmpString2);
-  item->setForeground(tmpbrush2);
-  item->setFont(tmpfont2);
-  
-  item2->setText(tmpString);
-  item2->setForeground(tmpbrush);
-  item2->setFont(tmpfont);
+  QListWidgetItem* item = widgetPlaylist->takeItem(row-1);
+  widgetPlaylist->insertItem(row,item);
     
   parent->engine->moveMedia(row,true);
   
-  widgetPlaylist->setCurrentRow(row-1);
+  //widgetPlaylist->setCurrentRow(row-1);
  }
  
  
@@ -189,27 +179,12 @@ void UIPlaylist::downItem()
   
  if((row<widgetPlaylist->count()-1)&&(row>=0))
  {
-  QListWidgetItem *item  = widgetPlaylist->item(row);
-  QString tmpString=item->text();
-  QBrush tmpbrush=item->foreground();
-  QFont tmpfont=item->font();
-  
-  QListWidgetItem* item2 = widgetPlaylist->item(row+1);
-  QString tmpString2=item2->text();
-  QBrush tmpbrush2=item2->foreground();
-  QFont tmpfont2=item2->font();
-  
-  item->setText(tmpString2);
-  item->setForeground(tmpbrush2);
-  item->setFont(tmpfont2);
-  
-  item2->setText(tmpString);
-  item2->setForeground(tmpbrush);
-  item2->setFont(tmpfont);
+  QListWidgetItem* item = widgetPlaylist->takeItem(row+1);
+  widgetPlaylist->insertItem(row,item);
     
   parent->engine->moveMedia(row,false);
   
-  widgetPlaylist->setCurrentRow(row+1);
+ // widgetPlaylist->setCurrentRow(row+1);
  }
   
 }
